@@ -366,24 +366,6 @@ gtk_clutter_actor_allocate (ClutterActor           *actor,
   clutter_actor_allocate (priv->texture, &child_box, flags);
 }
 
-static void
-gtk_clutter_actor_pick (ClutterActor       *actor,
-                        const ClutterColor *color)
-{
-  GtkClutterActorPrivate *priv = GTK_CLUTTER_ACTOR (actor)->priv;
-  ClutterActorIter iter;
-  ClutterActor *child;
-
-  CLUTTER_ACTOR_CLASS (gtk_clutter_actor_parent_class)->pick (actor, color);
-
-  /* we always have the backing texture below everything else */
-  clutter_actor_paint (priv->texture);
-
-  clutter_actor_iter_init (&iter, actor);
-  while (clutter_actor_iter_next (&iter, &child))
-    clutter_actor_paint (child);
-}
-
 static void
 gtk_clutter_actor_paint (ClutterActor *actor)
 {
@@ -553,9 +535,15 @@ gtk_clutter_actor_init (GtkClutterActor *self)
   if (!gtk_clutter_actor_use_image_surface () &&
       clutter_check_windowing_backend (CLUTTER_WINDOWING_X11))
     {
+      /* FIXME: write a GtkClutterWidgetContent that uses CoglTexturePixmapX11
+       * and a cairo_surface_t internally
+       */
       priv->texture = clutter_x11_texture_pixmap_new ();
 
+      G_GNUC_BEGIN_IGNORE_DEPRECATIONS
       clutter_texture_set_sync_size (CLUTTER_TEXTURE (priv->texture), FALSE);
+      G_GNUC_END_IGNORE_DEPRECATIONS
+
       clutter_actor_add_child (actor, priv->texture);
       clutter_actor_set_name (priv->texture, "Onscreen Texture");
       clutter_actor_show (priv->texture);
@@ -597,13 +585,9 @@ _gtk_clutter_actor_update (GtkClutterActor *actor,
 {
   GtkClutterActorPrivate *priv = actor->priv;
 
-  if (gtk_clutter_actor_use_image_surface ())
-    {
-      clutter_content_invalidate (priv->canvas);
-    }
-  else
 #if defined(CLUTTER_WINDOWING_X11)
-  if (clutter_check_windowing_backend (CLUTTER_WINDOWING_X11))
+  if (!gtk_clutter_actor_use_image_surface () &&
+      clutter_check_windowing_backend (CLUTTER_WINDOWING_X11))
     {
       clutter_x11_texture_pixmap_update_area (CLUTTER_X11_TEXTURE_PIXMAP (priv->texture),
 					      x, y, width, height);
@@ -611,7 +595,7 @@ _gtk_clutter_actor_update (GtkClutterActor *actor,
   else
 #endif
     {
-      /* ... */
+      clutter_content_invalidate (priv->canvas);
     }
 
   clutter_actor_queue_redraw (CLUTTER_ACTOR (actor));
